@@ -87,7 +87,8 @@ test_that("add_risktable() works with ggsurvfit()", {
   )
 
 
-  skip_on_os("linux")
+  # only check on mac
+  skip_on_ci()
   vdiffr::expect_doppelganger("sf1-risktable", lst_survfit2_risktable[[1]])
   vdiffr::expect_doppelganger("sf2-risktable", lst_survfit2_risktable[[2]])
   vdiffr::expect_doppelganger("sf3-risktable", lst_survfit2_risktable[[3]])
@@ -162,7 +163,8 @@ test_that("add_risktable() works with ggcuminc()", {
   )
 
 
-  skip_on_os("linux")
+  # only check on mac
+  skip_on_ci()
   vdiffr::expect_doppelganger("cuminc1-risktable", lst_cuminc_risktable[[1]])
   vdiffr::expect_doppelganger("cuminc2-risktable", lst_cuminc_risktable[[2]])
   vdiffr::expect_doppelganger("cuminc3-risktable", lst_cuminc_risktable[[3]])
@@ -176,7 +178,8 @@ test_that("add_risktable() works with ggcuminc() and multiple outcomes", {
     NA,
   )
 
-  skip_on_os("linux")
+  # only check on mac
+  skip_on_ci()
   vdiffr::expect_doppelganger("cuminc1-risktable-all-outcomes", lst_cuminc_risktable_outcomes[[1]])
   vdiffr::expect_doppelganger("cuminc2-risktable-all-outcomes", lst_cuminc_risktable_outcomes[[2]])
   vdiffr::expect_doppelganger("cuminc3-risktable-all-outcomes", lst_cuminc_risktable_outcomes[[3]])
@@ -238,7 +241,8 @@ test_that("add_risktable() custom stats", {
     NA
   )
 
-  skip_on_os("linux")
+  # only check on mac
+  skip_on_ci()
   vdiffr::expect_doppelganger("sf1-risktable-custom-stats-and-label", lst_custom_stats[[1]])
   vdiffr::expect_doppelganger("sf2-risktable-custom-stats-and-label", lst_custom_stats[[2]])
   vdiffr::expect_doppelganger("sf3-risktable-custom-stats-and-label", lst_custom_stats[[3]])
