@@ -54,7 +54,8 @@ test_that("ggcuminc() works with multiple outcomes", {
     NA
   )
 
-  skip_on_os("linux")
+  # only check on mac
+  skip_on_ci()
   vdiffr::expect_doppelganger("cuminc1-ggcuminc-all-outcomes", lst_ggcuminc_outcomes[[1]])
   vdiffr::expect_doppelganger("cuminc2-ggcuminc-all-outcomes", lst_ggcuminc_outcomes[[2]])
   vdiffr::expect_doppelganger("cuminc3-ggcuminc-all-outcomes", lst_ggcuminc_outcomes[[3]])
