@@ -20,7 +20,8 @@ test_that("stat_stepribbon() works", {
     NA
   )
 
-  skip_on_os("linux")
+  # only check on mac
+  skip_on_ci()
   vdiffr::expect_doppelganger("gg_stepribbon1", gg_stepribbon1)
   vdiffr::expect_doppelganger("gg_stepribbon2", gg_stepribbon2)
 })
